@@ -1,7 +1,10 @@
+use lib '.';
 use GD::Graph::xylines;
 use GD::Graph::xypoints;
 use GD::Graph::xylinespoints;
 
+my $gd;
+
 @data = ( 
 	[7, -6, 4, 3,4,5,6,7,7,7,7],
 	[ -1, 2, 3, 4,4,5,6,7,-1,-2,-6]
@@ -13,19 +16,19 @@ $my_graph->set(
 	title		=> 'I am the Walrus',
 	x_label	=> 'Monkey',
 	y_label	=> 'Donkey'
-	);
+);
 
-  my $gd = $my_graph->plot(\@data);
+$gd = $my_graph->plot(\@data);
 
-  open(IMG, '>xylines.png') or die $!;
-  binmode IMG;
-  print IMG $gd->png;
+open(IMG, '>xylines.png') or die $!;
+binmode IMG;
+print IMG $gd->png;
 
 
 @data = ( 
 	[7, -6, 4, 3,4,5,6,7,7,7,7],
 	[ -1, 2, 3, 4,4,5,6,7,-1,-2,-6]
-	);
+);
 	
 $my_graph = new GD::Graph::xypoints(600,400);
 
@@ -33,13 +36,13 @@ $my_graph->set(
 	title		=> 'I am the Walrus',
 	x_label	=> 'Monkey',
 	y_label	=> 'Donkey'
-	);
+);
 
-  my $gd = $my_graph->plot(\@data);
+  $gd = $my_graph->plot(\@data);
 
-  open(IMG, '>xypoints.png') or die $!;
-  binmode IMG;
-  print IMG $gd->png;
+open(IMG, '>xypoints.png') or die $!;
+binmode IMG;
+print IMG $gd->png;
 
 
 $my_graph = new GD::Graph::xylinespoints(600,400);
@@ -50,10 +53,8 @@ $my_graph->set(
 	y_label	=> 'Donkey'
 	);
 
-  my $gd = $my_graph->plot(\@data);
-
-  open(IMG, '>xylinespoints.png') or die $!;
-  binmode IMG;
-  print IMG $gd->png;
-
+$gd = $my_graph->plot(\@data);
 
+open(IMG, '>xylinespoints.png') or die $!;
+binmode IMG;
+print IMG $gd->png;
\ No newline at end of file
